@@ -27,7 +27,6 @@
 #define HAVE_BSEARCH 1
 /* #undef HAVE_CRYPT_H */
 #define HAVE_CURSES_H 1
-#define HAVE_CXXABI_H 1
 /* #undef HAVE_BFD_H */
 /* #undef HAVE_NCURSES_H */
 /* #undef HAVE_NDIR_H */
@@ -215,7 +214,7 @@
 /* #undef HAVE_PORT_CREATE */
 /* #undef HAVE_POSIX_FALLOCATE */
 #define HAVE_PREAD 1
-/* #undef HAVE_PAUSE_INSTRUCTION */
+#define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
@@ -345,10 +344,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define SIZEOF_CHAR 1
@@ -370,7 +369,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -395,7 +394,7 @@
 
 #define SOCKET_SIZE_TYPE socklen_t
 
-#define HAVE_MBSTATE_T
+#define HAVE_MBSTATE_T 1
 
 #define MAX_INDEXES 64
 
@@ -412,7 +411,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -430,15 +429,15 @@
 #define HAVE_WCTYPE_H 1
 #define HAVE_WCHAR_H 1
 #define HAVE_LANGINFO_H 1
-#define HAVE_MBRLEN
+#define HAVE_MBRLEN 1
 /* #undef HAVE_MBSCMP */
-#define HAVE_MBSRTOWCS
-#define HAVE_WCRTOMB
-#define HAVE_MBRTOWC
-#define HAVE_WCSCOLL
-#define HAVE_WCSDUP
-#define HAVE_WCWIDTH
-#define HAVE_WCTYPE
+#define HAVE_MBSRTOWCS 1
+#define HAVE_WCRTOMB 1
+#define HAVE_MBRTOWC 1
+#define HAVE_WCSCOLL 1
+#define HAVE_WCSDUP 1
+#define HAVE_WCWIDTH 1
+#define HAVE_WCTYPE 1
 #define HAVE_ISWLOWER 1
 #define HAVE_ISWUPPER 1
 #define HAVE_TOWLOWER 1
@@ -452,7 +451,7 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRNCASECMP 1
 #define HAVE_STRDUP 1
-#define HAVE_LANGINFO_CODESET 
+#define HAVE_LANGINFO_CODESET  1
 #define HAVE_TCGETATTR 1
 #define HAVE_FLOCKFILE 1
 
@@ -470,7 +469,8 @@
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
 /* #undef MY_ATOMIC_MODE_RWLOCKS */
-/* #undef HAVE_GCC_ATOMIC_BUILTINS */
+#define HAVE_GCC_ATOMIC_BUILTINS 1
+/* #undef HAVE_GCC_C11_ATOMICS */
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef HAVE_DECL_SHM_HUGETLB */
 /* #undef HAVE_LARGE_PAGES */
@@ -485,10 +485,10 @@
 
 #define TIME_WITH_SYS_TIME 1
 
-#define STACK_DIRECTION 1
+#define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "hppa"
+#define MACHINE_TYPE "amd64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -601,20 +601,20 @@
   Important storage engines (those that really need define 
   WITH_<ENGINE>_STORAGE_ENGINE for the whole server)
 */
-/* #undef WITH_MYISAM_STORAGE_ENGINE */
-/* #undef WITH_MYISAMMRG_STORAGE_ENGINE */
-/* #undef WITH_HEAP_STORAGE_ENGINE */
+#define WITH_MYISAM_STORAGE_ENGINE 1
+#define WITH_MYISAMMRG_STORAGE_ENGINE 1
+#define WITH_HEAP_STORAGE_ENGINE 1
 /* #undef WITH_INNOBASE_STORAGE_ENGINE */
-/* #undef WITH_XTRADB_STORAGE_ENGINE */
-/* #undef WITH_CSV_STORAGE_ENGINE */
-/* #undef WITH_PARTITION_STORAGE_ENGINE */
-/* #undef WITH_PERFSCHEMA_STORAGE_ENGINE */
+#define WITH_XTRADB_STORAGE_ENGINE 1
+#define WITH_CSV_STORAGE_ENGINE 1
+#define WITH_PARTITION_STORAGE_ENGINE 1
+#define WITH_PERFSCHEMA_STORAGE_ENGINE 1
 /* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
 #if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
 # define HAVE_NDB_BINLOG 1
 #endif
-/* #undef WITH_ARIA_STORAGE_ENGINE */
-/* #undef USE_ARIA_FOR_TMP_TABLES */
+#define WITH_ARIA_STORAGE_ENGINE 1
+#define USE_ARIA_FOR_TMP_TABLES 1
 
 #define DEFAULT_MYSQL_HOME "/usr/local"
 #define SHAREDIR "/usr/local/share/mysql"
@@ -629,16 +629,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 16
+#define MYSQL_VERSION_PATCH 20
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.16"
+#define PACKAGE_STRING "MySQL Server 10.0.20"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.16"
-#define VERSION "10.0.16"
+#define PACKAGE_VERSION "10.0.20"
+#define VERSION "10.0.20"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
